<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>command not found</source>
        <translation>comanda no trobada
</translation>
    </message>
</context>
<context>
    <name>@default</name>
    <message>
        <source>Operation successfully completed.</source>
        <translation>Operació completada amb èxit.</translation>
    </message>
    <message>
        <source>An error has occurs during the operation.</source>
        <translation>Ha ocorregut un error durant l&apos;operació.</translation>
    </message>
    <message>
        <source>An error has happened during the ped_disk_new call.</source>
        <translation>Ha ocorregut un error durant la crida ped_disk_new.</translation>
    </message>
    <message>
        <source>An error has happened during the ped_disk_get_partition call.</source>
        <translation>Ha ocorregut un error durant la crida ped_disk_get_partition.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_new call.</source>
        <translation>Ha ocorregut un error durant la crida a ped_partition_new.</translation>
    </message>
    <message>
        <source>An error has happened during ped_disk_add_partition call.</source>
        <translation>Ha ocorregut un error durant la crida a ped_disk_add_partition.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_set_system call.</source>
        <translation>Ha ocorregut un error durant la crida a ped_partition_set_system.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_set_flag call.</source>
        <translation>Ha ocorregut un error durant la crida a ped_partition_set_flag.</translation>
    </message>
    <message>
        <source>An error has happened during ped_disk_delete_partition call.</source>
        <translation>Ha ocorregut un error durant la crida a ped_disk_delete_partition.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>A program that create NTFS partitions.</source>
        <translation>Un programa que crea particiones NTFS.</translation>
    </message>
    <message>
        <source>A program that resize NTFS partitions.</source>
        <translation>Un programa que redimensiona particiones NTFS.</translation>
    </message>
    <message>
        <source>A program that create EXT3 partitions.</source>
        <translation>Un programa que crea particiones EXT3.</translation>
    </message>
    <message>
        <source>A program that create JFS partitions.</source>
        <translation>Un programa que crea particiones JFS.</translation>
    </message>
    <message>
        <source>A program that create XFS partitions.</source>
        <translation>Un programa que crea particiones XFS.</translation>
    </message>
    <message>
        <source>Cannot read /proc/partitions, QTParted cannot be used!.
Please use a kernel with /proc/partitions support.</source>
        <translation type="obsolete">No se puede leer /proc/partitions, ¡no se puede usar QTParted!
Por favor, use un núcleo con soporte para /proc/partitions.</translation>
    </message>
    <message>
        <source>Cannot get parted version.</source>
        <translation>No se puede obtener la versión de parted.</translation>
    </message>
    <message>
        <source>Parted is too old:
- installed parted version: %1.%2.%3
- required parted version: %4.%5.%6 (or better)

Parted homepage: http://www.gnu.org/software/parted/</source>
        <translation>Parted es demasiado viejo:
- versión de parted instalada:  %1.%2.%3
- versión de parted necesaria: %4.%5.%6 (o superior)

Página web de parted: http://www.gnu.org/software/parted/</translation>
    </message>
    <message>
        <source>Cannot umount partition device: %1.Please do it by hand first to commit the changes!</source>
        <translation>No es pot desmuntar el dispositiu de la partició: %1. ¡Si us plau, faci-ho manualment abans d&apos;efectuar els canvis!</translation>
    </message>
    <message>
        <source>Utility for mount a filesystem.</source>
        <translation>Utilitat per muntar un sistema de fitxers.</translation>
    </message>
    <message>
        <source>Utility for umount a filesystem.</source>
        <translation>Utilitat per desmuntar un sistema de fitxers.</translation>
    </message>
    <message>
        <source>Utility for grow a xfs filesystem.</source>
        <translation>Utilitat per fer crèixer un sistema de fitxers xfs.</translation>
    </message>
</context>
<context>
    <name>QP_ActionList</name>
    <message>
        <source>Getting info about partition %1.</source>
        <translation>Obtenint informació sobre la partició %1.</translation>
    </message>
    <message>
        <source>Creating partition.</source>
        <translation>Creant partició.</translation>
    </message>
    <message>
        <source>Preparation for removing a partition.</source>
        <translation>Preparant-se per esborrar una partició.</translation>
    </message>
    <message>
        <source>Removing a partition.</source>
        <translation>Esborrant una partició.</translation>
    </message>
    <message>
        <source>Preparation for resizing a partition.</source>
        <translation>Preparant-se para redimensionar una partició.</translation>
    </message>
    <message>
        <source>Resizing a partition.</source>
        <translation>Redimensionant una partició.</translation>
    </message>
    <message>
        <source>Preparation for activating a partition.</source>
        <translation>Preparant-se per activar una partició.</translation>
    </message>
    <message>
        <source>Activating a partition.</source>
        <translation>Activant una partició.</translation>
    </message>
    <message>
        <source>Preparation for formatting a partition.</source>
        <translation>Preparant-se per a formatar una partició.</translation>
    </message>
    <message>
        <source>Formatting a partition.</source>
        <translation>Formatant una partició.</translation>
    </message>
    <message>
        <source>Rescan of the disk.</source>
        <translation>Nou examen de disc.</translation>
    </message>
    <message>
        <source>Preparation for moving a partition.</source>
        <translation>Preparant-se per moure una partició.</translation>
    </message>
    <message>
        <source>Moving a partition.</source>
        <translation>Movent una partició.</translation>
    </message>
    <message>
        <source>All operations completed.</source>
        <translation>Totes les operacions han estat completades.</translation>
    </message>
    <message>
        <source>Critical error during ped_disk_new!</source>
        <translation>Error crític mentre ped_disk_new!</translation>
    </message>
    <message>
        <source>Critical error during ped_disk_duplicate!</source>
        <translation>Error crític mentre ped_disk_duplicate!</translation>
    </message>
    <message>
        <source>Preparation for hiding a partition.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hiding a partition.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_DriveList</name>
    <message>
        <source>No device found. Maybe you&apos;re not using root user?</source>
        <translation>No s&apos;ha trobat cap dispositiu. ¿Pot ser que no estigui identificat com a root?</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositiu</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Discs</translation>
    </message>
</context>
<context>
    <name>QP_FSExt3</name>
    <message>
        <source>Writing superblocks and filesystem.</source>
        <translation>Escrivint superblocks i sistema de fitxers.</translation>
    </message>
    <message>
        <source>Writing inode tables.</source>
        <translation>Escrivint taules d&apos;inodes.</translation>
    </message>
    <message>
        <source>There was a problem with mkfs.ext3.</source>
        <translation>Ha hagut un problema amb mkfs.ext3.</translation>
    </message>
</context>
<context>
    <name>QP_FSJfs</name>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation>No es pot fer més gran una partició si el dispositiu de disc està ocupat</translation>
    </message>
</context>
<context>
    <name>QP_FSNtfs</name>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation>No es pot fer més gran una partició si el dispositiu de disc està ocupat</translation>
    </message>
    <message>
        <source>Resizing in progress.</source>
        <translation>Redimensionament en progrés.</translation>
    </message>
    <message>
        <source>Syncing device.</source>
        <translation>Sincronitzant dispositiu.</translation>
    </message>
</context>
<context>
    <name>QP_FSReiserFS</name>
    <message>
        <source>No label</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_FSXfs</name>
    <message>
        <source>There was a problem with mkfs.xfs.</source>
        <translation>Ha aparegut un problema amb mkfs.xfs.</translation>
    </message>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation>No es pot fer més gran una partició si el dispositiu de disc està ocupat</translation>
    </message>
    <message>
        <source>Error during xfs_grow.</source>
        <translation>Error mentre xfs_grow.</translation>
    </message>
</context>
<context>
    <name>QP_LibParted</name>
    <message>
        <source>Can&apos;t move extended partitions.</source>
        <translation>No es poden moure particions exteses.</translation>
    </message>
    <message>
        <source>Can&apos;t move a partition onto itself. Try using resize, perhaps?</source>
        <translation>No es pot moure una partició sobre sí mateixa. Potser la vol redimensionar?</translation>
    </message>
    <message>
        <source>The partition is mounted.</source>
        <translation>La partició està muntada.</translation>
    </message>
    <message>
        <source>An error happen during ped_geometry_init call.</source>
        <translation>Se ha produit un error durant la crida a ped_geometry_init.</translation>
    </message>
    <message>
        <source>An error happen during ped_disk_set_partition_geom call.</source>
        <translation>Ha ocorregut un error durant la crida a ped_disk_set_partition_geom.</translation>
    </message>
    <message>
        <source>An error happen during ped_file_system_open call.</source>
        <translation>S&apos;ha produït un error mentre es feia la crida a ped_file_system_open.</translation>
    </message>
    <message>
        <source>An error happen during ped_file_system_resize call.</source>
        <translation>S&apos;ha produït un error mentre es feia la crida a ped_file_system_resize.</translation>
    </message>
    <message>
        <source>Scanning all disk partitions.</source>
        <translation>Examinant totes les particions del disc.</translation>
    </message>
    <message>
        <source>Partition %s is being used.</source>
        <translation>La partició %s està en ús.</translation>
    </message>
    <message>
        <source>Cannot change the active status on this partition</source>
        <translation>No es pot canviar l&apos;estat actiu d&apos;aquesta partició</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during set_system, please report it!</source>
        <translation>S&apos;ha trobat un error a QTParted mentre es feia set_system. Si us plau: ¡informi d&apos;ell!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during ped_file_system_type_get, please report it!</source>
        <translation>S&apos;ha trobat un error a QTParted mentre es feia ped_file_system_type_get. Si us plau, ¡informi d&apos;ell!</translation>
    </message>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>Aquesta és una partició virtual.  No pot modificar-la: utilitzi desfer per tornar.</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;resize&quot; scan, please report it!</source>
        <translation>S&apos;ha trobat un error a QTParted mentre s&apos;estava fent l&apos;examen per redimensionar. ¡Si us plau, informi d&apos;ell!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;mkfs&quot; scan, please report it!</source>
        <translation>S&apos;ha trobat un error a QTParted mentre es feia la creació del sistema de fitxers. ¡Si us plau, informi d&apos;ell!</translation>
    </message>
    <message>
        <source>Error committing device.
This can happen when a device is mounted in the disk.
Try to unmount all partitions on this disk.
Please read the FAQ for this kind of error!</source>
        <translation>Error al efectuar els canvis sobre el dispositiu.
Això pot passar quan un dispositiu està muntat al disc.
Provi de desmuntar totes les particiones d&apos;aquest disc.
¡Si us plau, llegeixi les Preguntes Més Freqüents per aquest tipus d&apos;error!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;move&quot; scan, please report it!</source>
        <translation>S&apos;ha trobat un error a QTParted mentre es movia una partició. ¡Si us plau, informi d&apos;ell!</translation>
    </message>
    <message>
        <source>Cannot change the hidden status on this partition</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_MainWindow</name>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Surt</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Quit from the application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <source>&amp;Property</source>
        <translation>&amp;Propietats</translation>
    </message>
    <message>
        <source>Property</source>
        <translation>Proprietats
</translation>
    </message>
    <message>
        <source>Property of the selected partition</source>
        <translation>Propietats de la partició seleccionada</translation>
    </message>
    <message>
        <source>&amp;Create</source>
        <translation>&amp;Crea</translation>
    </message>
    <message>
        <source>Create a new partition</source>
        <translation>Crea una nova partició</translation>
    </message>
    <message>
        <source>&amp;Resize</source>
        <translation>&amp;Redimensiona</translation>
    </message>
    <message>
        <source>Resize</source>
        <translation>Redimensiona

</translation>
    </message>
    <message>
        <source>Resize a partition</source>
        <translation>Redimensiona una partició</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Mou</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Mou</translation>
    </message>
    <message>
        <source>Move a partition</source>
        <translation>Mou una partició</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Esborra</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Esborra</translation>
    </message>
    <message>
        <source>Delete a new partition</source>
        <translation>Esborra una nova partició</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fitxer</translation>
    </message>
    <message>
        <source>&amp;Operations</source>
        <translation>&amp;Operacions</translation>
    </message>
    <message>
        <source>this is a %1 partition
it start at: %2 and end at: %3
it can grow left: %4 and right: %5
the filesystem is: %6</source>
        <translation type="unfinished">aquesta és una partició %1
comença a: %2 i acaba a: %3
pot créixer cap a l&apos;esquerra: %4 i cap a la dreta: %5
el sistema de fitxers és: %6</translation>
    </message>
    <message>
        <source>Enter &lt;b&gt;What&apos;s This&lt;/b&gt; modeIt enables the user to ask for help about widgets on the screen.</source>
        <translation>Introduir &lt;b&gt;Què és això?&lt;/b&gt; permet a l&apos;usuari demanar ajuda sobre els objectes de la pantalla.</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Crea</translation>
    </message>
    <message>
        <source>What&apos;s &amp;This</source>
        <translation>&amp;Què és això</translation>
    </message>
    <message>
        <source>What&apos;s This</source>
        <translation>Què és això</translation>
    </message>
    <message>
        <source>About QT</source>
        <translation>Sobre QT</translation>
    </message>
    <message>
        <source>Information about QT</source>
        <translation>Informació sobre QT</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>About &amp;QTParted</source>
        <translation>Sobre &amp;QTParted</translation>
    </message>
    <message>
        <source>About QTParted</source>
        <translation>Sobre QTParted</translation>
    </message>
    <message>
        <source>Information about QTParted</source>
        <translation>Informació sobre QTParted</translation>
    </message>
    <message>
        <source>About Q&amp;T</source>
        <translation>Sobre Q&amp;T</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>An internal error happened during partition scan.
This means that you cannot resize or move this partition.</source>
        <translation>S&apos;ha produït un error intern mentre s&apos;examinava la partició.
Això significa que es pot redimensionar o moure aquesta partició.</translation>
    </message>
    <message>
        <source>&amp;Configuration...</source>
        <translation>&amp;Configuració...</translation>
    </message>
    <message>
        <source>Configuration of QTParted</source>
        <translation>Configuració de QTParted</translation>
    </message>
    <message>
        <source>Open the configuration dialog</source>
        <translation>Obrir el diàleg de conficuració</translation>
    </message>
    <message>
        <source>&amp;Disks</source>
        <translation>&amp;Discs</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Opcions</translation>
    </message>
    <message>
        <source>Getting devices</source>
        <translation>Obtenint dispositius</translation>
    </message>
    <message>
        <source>load user settings</source>
        <translation>carrega preferències de  l&apos;usuari</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Llest</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Desfer</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfer</translation>
    </message>
    <message>
        <source>Undo last operation</source>
        <translation>Desfer la última operació</translation>
    </message>
    <message>
        <source>&amp;Commit</source>
        <translation>&amp;Aplica</translation>
    </message>
    <message>
        <source>Commit</source>
        <translation>Aplica</translation>
    </message>
    <message>
        <source>Commit all operations</source>
        <translation>Efectuar totes les operacions</translation>
    </message>
    <message>
        <source>Set Active...</source>
        <translation>Establir partició activa...</translation>
    </message>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>Aquesta és una partició virtual. Vosté no pot modificar-la: faci servir desfer per tornar.</translation>
    </message>
    <message>
        <source>primary</source>
        <translation>primària</translation>
    </message>
    <message>
        <source>logical</source>
        <translation>lògica</translation>
    </message>
    <message>
        <source>extended</source>
        <translation>extesa</translation>
    </message>
    <message>
        <source>(No Active on Drive)</source>
        <translation>(Cap activa al disc)</translation>
    </message>
    <message>
        <source>Currently active partition: %1
Change active partition to: %2

Are you sure you want to change the active partition?</source>
        <translation>Partició activa actualment: %1
Canvia la partició activa a: %2

¿Està segur de que vol canviar la partició activa?</translation>
    </message>
    <message>
        <source>&amp;Format</source>
        <translation>&amp;Formata</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formata</translation>
    </message>
    <message>
        <source>Format a new partition</source>
        <translation>Formata una nova partició</translation>
    </message>
    <message>
        <source>&amp;Device property</source>
        <translation>Propietats del &amp;dispositiu</translation>
    </message>
    <message>
        <source>&amp;Make a new Partition Table</source>
        <translation>&amp;Crea una nova taula de particions</translation>
    </message>
    <message>
        <source>This will make the partition table</source>
        <translation>Això crearà la taula de particions</translation>
    </message>
    <message>
        <source>You&apos;re going to loose all partition data! Are you sure? :)</source>
        <translation>Es perdran totes les dades de les particions! Està segur? :)</translation>
    </message>
    <message>
        <source>detected</source>
        <translation>detectada</translation>
    </message>
    <message>
        <source>none</source>
        <translation>cap</translation>
    </message>
    <message>
        <source>You&apos;re going to make a new partition table. Are you sure?
All data will be lost!</source>
        <translation>Es crearà una nova taula de particions. Està segur?
Es perdran totes les dades!</translation>
    </message>
    <message>
        <source>It was not possible to make a new partition table.</source>
        <translation>No ha estat possible crear una nova taula de particions.</translation>
    </message>
    <message>
        <source>Device status: readonly.</source>
        <translation>Estat del dispositiu: de només lectura.</translation>
    </message>
    <message>
        <source>Device status: busy.</source>
        <translation>Estat del dispositiu: ocupat.</translation>
    </message>
    <message>
        <source>Device status: available.</source>
        <translation>Estat del dispositiu: disponbile.</translation>
    </message>
    <message>
        <source>You&apos;re commiting all changes. Warning, you can lost data!
Make sure also that you&apos;re not commiting a busy device...
In other word PLEASE UMOUNT ALL PARTITIONS before commiting changes!</source>
        <translation>Està a punto de realitzar tots els canvis. Advertiment: ¡pot perdre dades!
Asseguri&apos;s també de que no farà els canvis sobre un dispositiu ocupat...
En altres paraules, ¡SI US PLAU, DESMUNTI TOTES LES PARTICIONS abans d&apos;efectuar els canvis!</translation>
    </message>
    <message>
        <source>&amp;Device</source>
        <translation>&amp;Dispositiu</translation>
    </message>
    <message>
        <source>See the property of this disk device</source>
        <translation>Veures les propietats d&apos;aquest dispositiu de disc</translation>
    </message>
    <message>
        <source>Some information about the disk device</source>
        <translation>Una mica d&apos;informació sobre el dispositiu de disc</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_NavView</name>
    <message>
        <source>The following drives have been detected:</source>
        <translation>S&apos;han detectat els següents discs:</translation>
    </message>
    <message>
        <source>Drive Info</source>
        <translation>Informació del disc</translation>
    </message>
    <message>
        <source>Device:</source>
        <translation>Dispositiu:</translation>
    </message>
    <message>
        <source>Model:</source>
        <translation>Model:</translation>
    </message>
    <message>
        <source>Capacity (Mb):</source>
        <translation>Capacitat (Mb):</translation>
    </message>
    <message>
        <source>Length sectors:</source>
        <translation>Longitud en sectors:</translation>
    </message>
    <message>
        <source>No Drive Selected</source>
        <translation>No s&apos;ha seleccionat cap disc</translation>
    </message>
    <message>
        <source>Status: </source>
        <translation>Estat:</translation>
    </message>
    <message>
        <source>readonly.</source>
        <translation>de només lectura.</translation>
    </message>
    <message>
        <source>busy.</source>
        <translation>ocupat.</translation>
    </message>
    <message>
        <source>available.</source>
        <translation>disponible.</translation>
    </message>
</context>
<context>
    <name>QP_PartInfo</name>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>Aquesta és una partició virtual. No pot modificar-la: faci servir desfer.</translation>
    </message>
    <message>
        <source>Bug during mkfs! Cannot format virtual partitions!</source>
        <translation>Fallada mentre mkfs! No es poden formatar particions virtuals!</translation>
    </message>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation type="obsolete">No se puede agrandar una partición si el dispositivo de disco está ocupado</translation>
    </message>
</context>
<context>
    <name>QP_RealListView</name>
    <message>
        <source>Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <source>Partition</source>
        <translation>Partició</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inici</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fi</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Mida</translation>
    </message>
    <message>
        <source>Used space</source>
        <translation>Espai emprat</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actiu</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Buit</translation>
    </message>
    <message>
        <source>Partition table</source>
        <translation>Taula de particions</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_UIConfig</name>
    <message>
        <source>Configuration</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>QTParted &amp;layout</source>
        <translation>&amp;Disposició de QTParted</translation>
    </message>
    <message>
        <source>Chart and ListBox</source>
        <translation>Gràfica i detalls</translation>
    </message>
    <message>
        <source>Only Chart</source>
        <translation>Només gràfica</translation>
    </message>
    <message>
        <source>Only ListBox</source>
        <translation>Només detalls</translation>
    </message>
    <message>
        <source>&amp;External Tools</source>
        <translation>Eines &amp;externes</translation>
    </message>
    <message>
        <source>&amp;Full executable path</source>
        <translation>&amp;Camí sencer de l&apos;executable</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;D&apos;Acord</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancel·la</translation>
    </message>
</context>
<context>
    <name>QP_UICreate</name>
    <message>
        <source>Create partition</source>
        <translation>Crear una partició</translation>
    </message>
    <message>
        <source>&amp;Size:</source>
        <translation>&amp;Mida:</translation>
    </message>
    <message>
        <source>Create &amp;as:</source>
        <translation>Crear &amp;com:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiqueta:</translation>
    </message>
    <message>
        <source>&amp;Partition Type:</source>
        <translation>Tipus de &amp;partició:</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posició</translation>
    </message>
    <message>
        <source>&amp;Beginning of unallocated space</source>
        <translation>&amp;Inici de l&apos;espai no utilitzat</translation>
    </message>
    <message>
        <source>&amp;End of unallocated space</source>
        <translation>&amp;Final de l&apos;espai no utilitzat</translation>
    </message>
    <message>
        <source>Pe&amp;rcent of unallocated space:</source>
        <translation>Pe&amp;rcentatge de l&apos;espai no utilitzat:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;D&apos;Acord</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancel·la</translation>
    </message>
</context>
<context>
    <name>QP_UIDeviceProperty</name>
    <message>
        <source>Device property</source>
        <translation>Propietats del dispositiu</translation>
    </message>
    <message>
        <source>Device short name</source>
        <translation>Nom curt del dispositiu</translation>
    </message>
    <message>
        <source>Device long name</source>
        <translation>Nom llarg del dispositiu</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Tanca</translation>
    </message>
</context>
<context>
    <name>QP_UIFormat</name>
    <message>
        <source>Format partition</source>
        <translation>Formatar partició</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;D&apos;Acord</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancel·la</translation>
    </message>
    <message>
        <source>&amp;Partition Type:</source>
        <translation>Tipus de &amp;partició:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiqueta:</translation>
    </message>
</context>
<context>
    <name>QP_UIProgress</name>
    <message>
        <source>Progress</source>
        <translation>Progrés</translation>
    </message>
    <message>
        <source>Progress:</source>
        <translation>Progrés:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;D&apos;acord</translation>
    </message>
    <message>
        <source>Time Left:</source>
        <translation>Temps restant:</translation>
    </message>
    <message>
        <source>Current operation:</source>
        <translation>Operació en curs:</translation>
    </message>
</context>
<context>
    <name>QP_UIResize</name>
    <message>
        <source>Resize partition</source>
        <translation>Redimensionar partició</translation>
    </message>
    <message>
        <source>Minimum Size:</source>
        <translation>Mida mínima:</translation>
    </message>
    <message>
        <source>Free Space &amp;Before:</source>
        <translation>Espai lliure &amp;abans:</translation>
    </message>
    <message>
        <source>New Size:</source>
        <translation>Nova mida:</translation>
    </message>
    <message>
        <source>Free Space &amp;After:</source>
        <translation>Espai lliure &amp;després:</translation>
    </message>
    <message>
        <source>It is recommended to backup your data before do this operation!</source>
        <translation>¡Es recomanable fer una còpia seguretat de les dades abans de realitzar aquesta operació!</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;D&apos;acord</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancel·la</translation>
    </message>
</context>
<context>
    <name>QP_dlgAbout</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;D&apos;acord</translation>
    </message>
</context>
<context>
    <name>QP_dlgCreate</name>
    <message>
        <source>This filesystem cannot be greater of %1</source>
        <translation>Aquest sistema de fitxers no pot ser més gran que %1</translation>
    </message>
</context>
<context>
    <name>QP_dlgDevProperty</name>
    <message>
        <source>Devfs is enabled.</source>
        <translation>Devfs està habilitat.</translation>
    </message>
    <message>
        <source>Devfs is disabled.</source>
        <translation>Devfs està deshabilitat.</translation>
    </message>
    <message>
        <source>Partition table: %1</source>
        <translation>Taula de particions: %1</translation>
    </message>
</context>
<context>
    <name>QP_dlgProgress</name>
    <message>
        <source>Initializing</source>
        <translation>Inicialitzant</translation>
    </message>
    <message>
        <source>Time Left: %1</source>
        <translation>Temps restant: %1</translation>
    </message>
    <message>
        <source>Operation: %1 of %2.
Current operation: %3</source>
        <translation>Operació: %1 de %2
Operació actual: %3</translation>
    </message>
    <message>
        <source>Operations completed sucessfully.</source>
        <translation>Les operacions s&apos;han completat amb èxit.</translation>
    </message>
</context>
<context>
    <name>QP_dlgResize</name>
    <message>
        <source>Resize partition</source>
        <translation>Redimensionar partició</translation>
    </message>
    <message>
        <source>Minimum Size: %1 MB</source>
        <translation>Mida mínima: %1 MB</translation>
    </message>
    <message>
        <source>Move partition</source>
        <translation>Moure partició</translation>
    </message>
</context>
</TS>
